This is a package that provides implementations of three functions important in machine learning and data science:

- Transposing matrices with `transpose2d`
- Cross-correlation (commonly called convolution) of matrices with kernels with `convolution2d`
- Sampling a 1D array / list using a sliding window with `window1d`